%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [out step] = run_HB(HBunits,aspace,np,L,E,I,R)
% This function runs a standard HB vehicle across the bridge, returning a
% matrix of moments and shears for each vehicle position

no_points = np;
step = (sum(L)+2*1.8+aspace)/no_points;

for i = 0:no_points
    ax(1) = i*step;
    ax(2) = ax(1) - 1.8;
    ax(3) = ax(2) - aspace;
    ax(4) = ax(3) - 1.8;
    
    % check load is on the bridge
    % and assign to correct span if it is.
    for j = 1:4
        span = 1; load = 10*HBunits;
        if ax(j) < 0
            ax(j) = 0; load = 0;
        else
            for k = 1:length(L)
                if ax(j) > L(k)
                    % put it on the next span
                    % loads off the end of the beam are assigned to the 
                    % imaginary next span and will not be assigned to any 
                    % span of the analysis - see LM_span.m
                    ax(j) = ax(j) - L(k);
                    span = k+1;
                    if span > length(L)
                        a(j) = 0; load = 0; 
                    end
                end
            end
        end
        LM(j,:) = [span,2,load,ax(j),0];
    end
    temp = CBA(L,E,I,R,LM,'r'); % (x, M, V, d)
    [nr nc] = size(temp);
    out(1,i+2) = i*step;
    if i == 0
        out(2:nr+1,1) = temp(:,1);
    end
    out(2:nr+1,i+2) = temp(:,2);
end
